@@ -1,4 +1,3 @@
-#!/usr/bin/python3
 # SPDX-License-Identifier: MIT
 
 import glob
@@ -435,7 +434,6 @@ class SleepValidator(AmdTool):
                 continue
             self.db.record_debug(
                 f"Woke up from input source {device} ({self.wakeup_count[device]}->{count})",
-                "💤",
             )
         self.wakeup_count = wakeup_count
 
@@ -470,7 +468,7 @@ class SleepValidator(AmdTool):
                 self.db.record_debug(f"HW sleep statistics file {p} is missing")
         if not self.hw_sleep_duration:
             self.db.record_cycle_data("Did not reach hardware sleep state", "❌")
-        return self.hw_sleep_duration
+        return self.hw_sleep_duration > 0
 
     def capture_command_line(self):
         """Capture the kernel command line to debug"""
@@ -583,7 +581,6 @@ class SleepValidator(AmdTool):
                     if bit_changed & BIT(bit):
                         self.db.record_debug(
                             f"Idle mask bit {bit} (0x{BIT(bit):x}) changed during suspend",
-                            "○",
                         )
         if self.upep:
             if self.upep_microsoft:
@@ -661,10 +658,10 @@ class SleepValidator(AmdTool):
             check()
         self.db.record_cycle(
             self.requested_duration,
-            self.active_gpios,
-            self.wakeup_irqs,
-            self.kernel_duration,
-            self.hw_sleep_duration,
+            ",".join(str(gpio) for gpio in self.active_gpios),
+            ",".join(str(irq) for irq in self.wakeup_irqs),
+            int(self.kernel_duration),
+            int(self.hw_sleep_duration),
         )
 
     def prep(self):
